@@ -4,7 +4,7 @@ package Dist::Zilla::MintingProfile::Author::ETHER;
 # ABSTRACT: Mint distributions like ETHER does
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile';
@@ -42,7 +42,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -109,7 +109,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 irc://irc.perl.org/#distzilla.
