@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.102-14-gb7ccdb2
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.103-6-g5e145e3
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use Moose;
 with
@@ -79,9 +79,11 @@ has licence => (
     lazy => 1,
     default => sub {
         my $self = shift;
+        my $authority = $self->payload->{'Authority.authority'} // 'cpan:ETHER';
         $self->payload->{licence}
             // $self->payload->{license}
-            // (($self->payload->{'Authority.authority'} // 'cpan:ETHER') eq 'cpan:ETHER'
+            # licenSe is US-only; known non-American authors will be treated appropriately.
+            // ((any { $authority eq "cpan:$_" } qw(ETHER ABERGMAN AVAR BINGOS BOBTFISH CHOLET FLORA GETTY ILMARI JAWNSY JQUELIN LEONT LLAP MSTROUT NUFFIN PERIGRIN PHAYLON))
                 ? 'LICENCE' : 'LICENSE');
     },
 );
@@ -444,7 +446,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -975,7 +977,7 @@ install or are otherwise problematic.
 
 If a F<weaver.ini> is present in the distribution, pod is woven using it;
 otherwise, the behaviour is as with a F<weaver.ini> containing the single line
-C<[@Author::ETHER]>.
+C<[@Author::ETHER]> (see L<Pod::Weaver::PluginBundle::Author::ETHER>).
 
 =head1 NAMING SCHEME
 
@@ -1004,7 +1006,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 irc://irc.perl.org/#distzilla.
