@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -59,7 +59,7 @@ sub configure
     ? "bugs may be submitted through L<$bugtracker_web>."
     : (),
 
-    $distmeta->{resources}{x_MailingList} ? 'There is also a mailing list available for users of this distribution, at' . "\n" . $distmeta->{resources}{x_MailingList} . '.' : (),
+    $distmeta->{resources}{x_MailingList} ? 'There is also a mailing list available for users of this distribution, at' . "\nL<" . $distmeta->{resources}{x_MailingList} . '>.' : (),
 
     $distmeta->{resources}{x_IRC}
         ? 'There is also an irc channel available for users of this distribution, at' . "\n" . $distmeta->{resources}{x_IRC} . '.'
@@ -74,7 +74,7 @@ SUPPORT
         ],
 
         [ 'AllowOverride' => 'allow override SUPPORT' => {
-               header_re => '^SUPPORT',
+               header_re => '^(SUPPORT|BUGS)',
                action => 'prepend',
                match_anywhere => 0,
             },
@@ -167,7 +167,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
@@ -232,7 +232,7 @@ following F<weaver.ini>, minus some optimizations:
     main_module_only = 0
     text = <template>
     [AllowOverride / allow override SUPPORT]
-    header_re = ^SUPPORT
+    header_re = ^(SUPPORT|BUGS)
     action = prepend
     match_anywhere = 0
 
@@ -263,7 +263,7 @@ This is also equivalent (other than section ordering) to:
     main_module_only = 0
     text = <template>
     [AllowOverride / allow override SUPPORT]
-    header_re = ^SUPPORT
+    header_re = ^(SUPPORT|BUGS)
     action = prepend
     match_anywhere = 0
 
@@ -340,7 +340,7 @@ Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Di
 (or L<bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org|mailto:bug-Dist-Zilla-PluginBundle-Author-ETHER@rt.cpan.org>).
 
 There is also a mailing list available for users of this distribution, at
-http://dzil.org/#mailing-list.
+L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
 irc://irc.perl.org/#distzilla.
